@@ -32,16 +32,16 @@ class TdxClient(object):
         self.reports = ReportManager(self.dispatcher)
         self.security_roles = SecurityRoleManager(self.dispatcher)
 
-        self._org_apps = {}
+        self.apps = {}
 
         for a in self.applications.all():
             if a.app_class == "TDAssets":
-                self._org_apps[a.id] = AssetApplication(self.dispatcher, a.id)
+                self.apps[a.id] = AssetApplication(self.dispatcher, a.id)
             elif a.app_class == "TDTickets":
-                self._org_apps[a.id] = TicketApplication(self.dispatcher, a.id)
+                self.apps[a.id] = TicketApplication(self.dispatcher, a.id)
 
     def asset_app(self, app_id: int) -> AssetApplication:
-        return self._org_apps[app_id]
+        return self.apps[app_id]
 
     def ticket_app(self, app_id: int) -> TicketApplication:
-        return self._org_apps[app_id]
+        return self.apps[app_id]
