@@ -225,5 +225,5 @@ class RequestsBackend(object):
                 raise Exception(
                     f"{response.status_code}: {msg['Message']} (ID: {msg['ID']})"
                 )
-            except (JSONDecodeError, KeyError):
+            except (JSONDecodeError, KeyError, TypeError):
                 raise Exception(f"{response.status_code}: {response.text}")
