@@ -7,5 +7,8 @@ from tdxapi.enums.component import Component
 from tdxapi.enums.component_function import ComponentFunction
 from tdxapi.enums.feed_item_type import FeedItemType
 from tdxapi.enums.license_type import LicenseType
+from tdxapi.enums.sla_start_basis import SlaStartBasis
 from tdxapi.enums.status_class import StatusClass
+from tdxapi.enums.ticket_class import TicketClass
+from tdxapi.enums.time_zone import TimeZone
 from tdxapi.enums.update_type import UpdateType
