@@ -254,10 +254,7 @@ class AssetManager(TdxManager, TdxAppMixin, TdxCustomAttributeMixin):
         filename: Optional[str] = None,
         mimetype: Optional[str] = None,
     ) -> Attachment:
-        """Uploads an attachment to an asset.
-
-        The file should be included as part of the submission's form data.
-        """
+        """Uploads an attachment to an asset."""
         return self.dispatcher.send(
             self.add_attachment.method,
             self.add_attachment.url.format(appId=self.app_id, id=asset_id),
