@@ -13,8 +13,6 @@ from tdxapi.models.configuration_relationship_type_search import (
 
 @attr.s
 class ConfigurationRelationshipTypeManager(TdxManager, TdxAppMixin):
-    __tdx_section__ = "ConfigurationRelationshipTypes"
-
     @tdx_method("GET", "/api/{appId}/cmdb/relationshiptypes/{id}")
     def get(self, relationship_type_id: int) -> ConfigurationRelationshipType:
         """Gets a relationship type."""
@@ -78,7 +76,9 @@ class ConfigurationRelationshipTypeManager(TdxManager, TdxAppMixin):
         helpers.save_model(relationship_type, self, force)
 
     @tdx_method("POST", "/api/{appId}/cmdb/relationshiptypes")
-    def _insert(self, relationship_type):
+    def _insert(
+        self, relationship_type: ConfigurationRelationshipType
+    ) -> ConfigurationRelationshipType:
         """Creates a configuration relationship type."""
         return self.dispatcher.send(
             self._insert.method,
@@ -90,7 +90,9 @@ class ConfigurationRelationshipTypeManager(TdxManager, TdxAppMixin):
         )
 
     @tdx_method("PUT", "/api/{appId}/cmdb/relationshiptypes/{id}")
-    def _update(self, relationship_type):
+    def _update(
+        self, relationship_type: ConfigurationRelationshipType
+    ) -> ConfigurationRelationshipType:
         """Edits an existing configuration relationship type."""
         return self.dispatcher.send(
             self._update.method,
