@@ -11,8 +11,6 @@ from tdxapi.models.product_type_search import ProductTypeSearch
 
 @attr.s
 class ProductTypeManager(TdxManager, TdxAppMixin):
-    __tdx_section__ = "ProductTypes"
-
     @tdx_method("GET", "/api/{appId}/assets/models/types/{id}")
     def get(self, product_type_id: int) -> ProductType:
         """Gets a product type."""
@@ -89,7 +87,7 @@ class ProductTypeManager(TdxManager, TdxAppMixin):
         helpers.update_model(product_type, updated_model)
 
     @tdx_method("POST", "/api/{appId}/assets/models/types")
-    def _insert(self, product_type):
+    def _insert(self, product_type: ProductType) -> ProductType:
         """Creates a new product type."""
         return self.dispatcher.send(
             self._insert.method,
@@ -105,7 +103,9 @@ class ProductTypeManager(TdxManager, TdxAppMixin):
         "/api/{appId}/assets/models/types/{id}"
         "?cascadeActiveStatus={cascadeActiveStatus}",
     )
-    def _update(self, product_type, cascade_status=False):
+    def _update(
+        self, product_type: ProductType, cascade_status: Optional[bool] = False
+    ) -> ProductType:
         """Edits a product type."""
         return self.dispatcher.send(
             self._update.method,
