@@ -12,8 +12,6 @@ from tdxapi.models.security_role_search import SecurityRoleSearch
 
 @attr.s
 class SecurityRoleManager(TdxManager):
-    __tdx_section__ = "SecurityRoles"
-
     @tdx_method("GET", "/api/securityroles/{id}")
     def get(self, security_role_id: str) -> SecurityRole:
         """Gets a security role."""
@@ -98,7 +96,9 @@ class SecurityRoleManager(TdxManager):
     @tdx_method(
         "POST", "/api/securityroles?useDefaultPermissions={useDefaultPermissions}"
     )
-    def _insert(self, security_role, default_permissions=False):
+    def _insert(
+        self, security_role: SecurityRole, default_permissions: Optional[bool] = False
+    ) -> SecurityRole:
         """Creates a security role."""
         return self.dispatcher.send(
             self._insert.method,
@@ -113,7 +113,9 @@ class SecurityRoleManager(TdxManager):
         "PUT",
         "/api/securityroles/{id}?useDefaultPermissions={useDefaultPermissions}",
     )
-    def _update(self, security_role, default_permissions=False):
+    def _update(
+        self, security_role: SecurityRole, default_permissions: Optional[bool] = False
+    ) -> SecurityRole:
         """Edits the specified security role."""
         return self.dispatcher.send(
             self._update.method,
